<p align="center">
<img alt="Codacy grade" src="https://img.shields.io/codacy/grade/36695d0fb1c648fbb8e0cb00f3612c7e">
<img src="https://scrutinizer-ci.com/g/dotX12/waio/badges/quality-score.png?b=master" alt="https://scrutinizer-ci.com/g/dotX12/waio/">
<img src="https://scrutinizer-ci.com/g/dotX12/waio/badges/code-intelligence.svg?b=master" alt="https://scrutinizer-ci.com/g/dotX12/waio/">
<img src="https://img.shields.io/testspace/tests/dotX12/66672/master" alt="Testspace tests">
<img src="https://scrutinizer-ci.com/g/dotX12/waio/badges/build.png?b=master" alt="https://scrutinizer-ci.com/g/dotX12/waio/">
<img src="https://badge.fury.io/py/waio.svg" alt="https://badge.fury.io/py/waio">
<img src="https://img.shields.io/github/license/dotX12/waio.svg" alt="https://github.com/dotX12/waio/blob/master/LICENSE.md">
<img src="https://img.shields.io/github/last-commit/dotX12/waio" alt="GitHub last commit">
<br><br>
<img width="1000" src="docs/assets/images/readme_footer.png">
 🤖 waio - is a pretty simple and fully asynchronous framework for WhatsApp Business API written in Python 3.7 with asyncio and aiohttp.
Used API official Facebook partner - <a href="https://gupshup.io">Gupshup.io</a>

-----
</p>


You can create an account and use a **Sandbox** to develop a bot
and test functionality, and when you finish - create your own business
number and transfer the functionality to your number,
make verification (check mark) and be cool!

## Official waio resources:
- Documentation: [readthedocs](https://waio.readthedocs.io/)
- Community RU: [@waioru](https://t.me/waioru)
- PyPI: [waio](https://pypi.python.org/pypi/waio)
- Source: [Github repo](https://github.com/dotX12/waio)
